==================
Welcome to Covasim
==================

Covasim is a stochastic agent-based simulator, written in Python, for exploring and analyzing the COVID-19 epidemic. 

**There's a lot here, where should I start?** Take a quick look at the overview, which provides a general introduction. Then when you're ready to sink your teeth in, the tutorials will help you get started using Covasim.

Full contents
=============

.. toctree::
   :maxdepth: 4

   overview
   tutorials
   whatsnew
   parameters
   data
   faq
   glossary
   contributing
   modules